#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""calculate the statistics of all *.dats in current dir"""

from glob import iglob
from statistics import median
from warnings import filterwarnings as filter_warnings


def main() -> int:
    """entry / main function"""

    parsed_data: dict[str, dict[str, tuple[float, ...]]] = {}

    for dat in iglob("*.dat"):
        print(f"parsing {dat!r}")

        manager, context = dat[:-4].split("-", maxsplit=1)

        if manager not in parsed_data:
            parsed_data[manager] = {}

        with open(dat, "r") as data:
            parsed_data[manager][context] = tuple(map(float, data.readlines()))

    print()

    ranking: dict[str, dict[str, float]] = {}

    for manager, ctxs in sorted(parsed_data.items()):
        print(f"statistics for {manager!r}")

        for ctx, ctxd in sorted(ctxs.items()):
            print(f"  category {ctx!r} :")

            rank: dict[str, float] = {
                "average": sum(ctxd) / len(ctxd),
                "median": median(ctxd),
                "total": sum(ctxd),
            }

            if manager not in ranking:
                ranking[manager] = {}

            ranking[manager][ctx] = rank["total"]

            for field, val in rank.items():
                print(f"    {field} : {val:.2f}")

        print()

    print("=== leaderboard ===\n")

    for cat in ranking[tuple(ranking.keys())[0]]:
        print(f"in category {cat!r}")

        for place, (manager, rank) in enumerate(
            sorted(ranking.items(), key=lambda v: v[1][cat]), 1
        ):
            print(f"  #{place} {manager}")

        print()

    print("in total")

    for place, (manager, rank) in enumerate(
        sorted(ranking.items(), key=lambda v: sum(v[1].values())), 1
    ):
        print(f"  #{place} {manager}")

    return 0


if __name__ == "__main__":
    assert main.__annotations__.get("return") is int, "main() should return an integer"

    filter_warnings("error", category=Warning)
    raise SystemExit(main())
